import { __decorate, __metadata, __param } from 'tslib';
import { ElementRef, Input, Directive, InjectionToken, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable, NgModule, Injector, INJECTOR, Pipe } from '@angular/core';
import { CommonModule, DatePipe } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { PopoverModule } from 'ngx-bootstrap/popover';
import { BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TimepickerModule } from 'ngx-bootstrap';
import { ToastrModule, ToastrService } from 'ngx-toastr';
import { MatSnackBarModule, MatSnackBar } from '@angular/material/snack-bar';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { map, startWith } from 'rxjs/operators';
import { forkJoin, BehaviorSubject, Subscription, interval } from 'rxjs';
import * as moment_ from 'moment';
import distanceInWordsToNow from 'date-fns/formatDistanceToNow';
import es from 'date-fns/locale/es';
import en from 'date-fns/locale/en-US';
import { DomSanitizer } from '@angular/platform-browser';
import { over } from 'stompjs';
import * as SockJS from 'sockjs-client';

let HighlightDirective = class HighlightDirective {
    constructor(el) {
        this.el = el;
        this.searchText = undefined;
        this.caseSensitive = true;
        this.viewRendered = false;
        this.WRAPPER_TOKEN = '==--==##';
    }
    get caseSensitivity() { return this.caseSensitive ? '' : 'i'; }
    ngOnChanges(changes) {
        this.highlightSearchText();
    }
    ngAfterViewInit() {
        this.highlightSearchText();
    }
    ngAfterViewChecked() {
        this.viewRendered = true;
    }
    highlightSearchText() {
        // initial ngChage call will result with null \ undefined.
        if (!this.searchText) {
            // when user deletes all text the searchText is set to '' we need to remove all marks.
            if (this.viewRendered) {
                this.removePreviouslyMarkedTextInNode();
            }
            return;
        }
        if (this.el.nativeElement) {
            this.removePreviouslyMarkedTextInNode();
            this.markMatchedTextTokens(this.el.nativeElement);
        }
    }
    markMatchedTextTokens(htmlNode) {
        const _searchText = this.getSearchText();
        const searchRegex = new RegExp(_searchText, 'gm' + this.caseSensitivity);
        const _searchTextUniqueTokens = this.getUniqueTokenWrappedSearchText();
        const searchRegexUniqueTokens = new RegExp(_searchTextUniqueTokens, 'gm' + this.caseSensitivity);
        this.traverseHtmlElementsTree(htmlNode, e => {
            this.traverseNodesInElement(htmlNode.childNodes, node => this.wrapUniqueTokensAroundMatchedText(node, searchRegex));
        });
        this.markMatchedTextAndRemoveUniqueTokens(htmlNode, searchRegexUniqueTokens);
    }
    markMatchedTextAndRemoveUniqueTokens(htmlNode, searchRegex) {
        if (htmlNode.innerHTML) {
            const innerHtml = htmlNode.innerHTML;
            const newHtml = innerHtml.replace(searchRegex, match => {
                const wrapperLength = this.WRAPPER_TOKEN.length;
                const markedStr = match.substr(wrapperLength, match.length - (wrapperLength * 2));
                return `<mark>${markedStr}</mark>`;
            });
            htmlNode.innerHTML = newHtml;
        }
    }
    traverseNodesInElement(nodes, visitCallback) {
        nodes.forEach(node => {
            if (node.nodeType === 3) {
                visitCallback(node);
            }
        });
    }
    wrapUniqueTokensAroundMatchedText(htmlNode, searchRegex) {
        const innerText = htmlNode.nodeValue;
        const newText = innerText.replace(searchRegex, `${this.WRAPPER_TOKEN}$&${this.WRAPPER_TOKEN}`);
        htmlNode.nodeValue = newText;
    }
    traverseHtmlElementsTree(currentNode, visitCallback) {
        if (currentNode) {
            visitCallback(currentNode);
        }
        /* tslint:disable:prefer-for-of */
        for (let i = 0; i < currentNode.children.length; i++) {
            const childNode = currentNode.children[i];
            this.markMatchedTextTokens(childNode);
        }
    }
    removePreviouslyMarkedTextInNode() {
        const node = this.el.nativeElement;
        const markingPattern = new RegExp('<mark>|<\/mark>', 'g');
        const cleanText = node.innerHTML.replace(markingPattern, '');
        node.innerHTML = cleanText;
    }
    // private highlightedNewTextInNode() {
    //   const node = this.el.nativeElement;
    //   const htmlNegativeLookaheadPattern = '(?![^<>]*>)';
    //   const searchTextPattern = this.getSearchText();
    //   const searchRegex = new RegExp(searchTextPattern + htmlNegativeLookaheadPattern, 'gmi');
    //   const markedText = node.innerHTML.replace(searchRegex, '<mark>$&</mark>');
    //   node.innerHTML = markedText;
    // }
    getSearchText() {
        let escapedSearchText = `${this.escapeRegExp(this.searchText)}`;
        const spaceToMultiMatchRegex = new RegExp(' ', 'gm' + this.caseSensitivity);
        escapedSearchText = escapedSearchText.replace(spaceToMultiMatchRegex, '|');
        return escapedSearchText;
    }
    getUniqueTokenWrappedSearchText() {
        let escapedSearchText = this.escapeRegExp(this.searchText);
        const spaceToMultiMatchRegex = new RegExp(' ', 'gm' + this.caseSensitivity);
        escapedSearchText = escapedSearchText.replace(spaceToMultiMatchRegex, `${this.WRAPPER_TOKEN}|${this.WRAPPER_TOKEN}`);
        escapedSearchText = `${this.WRAPPER_TOKEN}${escapedSearchText}${this.WRAPPER_TOKEN}`;
        return escapedSearchText;
    }
    escapeRegExp(str) {
        return str.replace('/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/gi', '\\$&');
    }
};
HighlightDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], HighlightDirective.prototype, "searchText", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], HighlightDirective.prototype, "caseSensitive", void 0);
HighlightDirective = __decorate([
    Directive({
        selector: '[xdfHighlight]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], HighlightDirective);

const INITSERVICE_OPTIONS = new InjectionToken('forRoot() MyService configuration.');
let InitCommonsService = class InitCommonsService {
    constructor(config, translate, http) {
        this.config = config;
        this.translate = translate;
        this.http = http;
        this.definitionList = new Map();
        this.definitions = new Map();
    }
    initializeApp() {
        console.log('Init application');
        this.translate.setDefaultLang(this.config.language);
        return this.http.get('./assets/definitions/definitions.json').pipe(map(data => {
            const requestList = new Array();
            data.forEach(element => {
                const keys = Object.keys(element);
                const key = keys[0];
                const url = element[key];
                this.definitionList.set(key, url);
                requestList.push(this.http.get(url));
            });
            forkJoin(requestList).subscribe(list => {
                list.forEach(it => {
                    const keyName = 'name';
                    this.definitions.set(it[keyName], it);
                });
            });
        })).toPromise();
    }
};
InitCommonsService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] },
    { type: TranslateService },
    { type: HttpClient }
];
InitCommonsService.ngInjectableDef = ɵɵdefineInjectable({ factory: function InitCommonsService_Factory() { return new InitCommonsService(ɵɵinject(INITSERVICE_OPTIONS), ɵɵinject(TranslateService), ɵɵinject(HttpClient)); }, token: InitCommonsService, providedIn: "root" });
InitCommonsService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(INITSERVICE_OPTIONS)),
    __metadata("design:paramtypes", [Object, TranslateService,
        HttpClient])
], InitCommonsService);

var XdfCommonsModule_1;
let XdfCommonsModule = XdfCommonsModule_1 = class XdfCommonsModule {
    static forRoot(options = null) {
        return ({
            ngModule: XdfCommonsModule_1,
            providers: [
                {
                    provide: INITSERVICE_OPTIONS,
                    useValue: options
                }
            ]
        });
    }
};
XdfCommonsModule = XdfCommonsModule_1 = __decorate([
    NgModule({
        declarations: [
            HighlightDirective
        ],
        imports: [
            FormsModule,
            CommonModule,
            ReactiveFormsModule,
            TranslateModule,
            ToastrModule.forRoot(),
            MatSnackBarModule,
            PopoverModule.forRoot(),
            BsDatepickerModule.forRoot(),
            TimepickerModule.forRoot()
        ],
        exports: []
    })
], XdfCommonsModule);

class Pagination {
}
const DIRECTION = {
    asc: 'asc',
    desc: 'desc'
};
class SortField {
    constructor() {
        this.direction = DIRECTION.asc;
    }
}

class User {
}

let AuthenticationService = class AuthenticationService {
    constructor() {
        if (localStorage.getItem('currentUser') && localStorage.getItem('currentUser') !== 'undefined') {
            this.currentUserSubject = new BehaviorSubject(JSON.parse(localStorage.getItem('currentUser')));
            this.currentUser = this.currentUserSubject.asObservable();
        }
    }
    get currentUserValue() {
        return this.currentUserSubject ? this.currentUserSubject.value : undefined;
    }
};
AuthenticationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function AuthenticationService_Factory() { return new AuthenticationService(); }, token: AuthenticationService, providedIn: "root" });
AuthenticationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [])
], AuthenticationService);

var NotificationType;
(function (NotificationType) {
    NotificationType["success"] = "success";
    NotificationType["info"] = "info";
    NotificationType["warning"] = "warning";
    NotificationType["error"] = "error";
})(NotificationType || (NotificationType = {}));
let NotificationService = class NotificationService {
};
NotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NotificationService_Factory() { return new NotificationService(); }, token: NotificationService, providedIn: "root" });
NotificationService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], NotificationService);

let ToastNotificationService = class ToastNotificationService {
    constructor(injector, translate) {
        this.injector = injector;
        this.translate = translate;
        this.config = {
            closeButton: true,
            tapToDismiss: false,
            enableHtml: false,
            progressBar: false,
            newestOnTop: false,
            timeOut: 3000,
            positionClass: 'toast-top-right',
            extendedTimeOut: 1000,
            disableTimeOut: false,
            maxOpened: 0,
            easeTime: 300
        };
    }
    showMessage(_message, _title = '', type = NotificationType.info) {
        const toastr = this.injector.get(ToastrService);
        switch (type) {
            case NotificationType.success:
                toastr.success(_message, _title, this.config);
                break;
            case NotificationType.info:
                toastr.info(_message, _title, this.config);
                break;
            case NotificationType.warning:
                toastr.warning(_message, _title, this.config);
                break;
            case NotificationType.error:
                toastr.error(_message, _title, this.config);
                break;
        }
    }
};
ToastNotificationService.ctorParameters = () => [
    { type: Injector },
    { type: TranslateService }
];
ToastNotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ToastNotificationService_Factory() { return new ToastNotificationService(ɵɵinject(INJECTOR), ɵɵinject(TranslateService)); }, token: ToastNotificationService, providedIn: "root" });
ToastNotificationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [Injector, TranslateService])
], ToastNotificationService);

let SnackbarNotificationService = class SnackbarNotificationService {
    constructor(injector, translate) {
        this.injector = injector;
        this.translate = translate;
    }
    showMessage(message, title = '', type = NotificationType.info) {
        const _snackBar = this.injector.get(MatSnackBar);
        switch (type) {
            case NotificationType.success:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['success-snackbar']
                });
                break;
            case NotificationType.info:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['info-snackbar']
                });
                break;
            case NotificationType.warning:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['warning-snackbar']
                });
                break;
            case NotificationType.error:
                _snackBar.open(message, 'close', {
                    duration: 2000
                });
                break;
        }
    }
};
SnackbarNotificationService.ctorParameters = () => [
    { type: Injector },
    { type: TranslateService }
];
SnackbarNotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function SnackbarNotificationService_Factory() { return new SnackbarNotificationService(ɵɵinject(INJECTOR), ɵɵinject(TranslateService)); }, token: SnackbarNotificationService, providedIn: "root" });
SnackbarNotificationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [Injector, TranslateService])
], SnackbarNotificationService);

let ErrorsHandler = class ErrorsHandler {
    constructor(notificationService, translate) {
        this.notificationService = notificationService;
        this.translate = translate;
    }
    handleError(error) {
        if (!navigator.onLine) {
            // Handle offline error
            console.error('Browser Offline!');
        }
        else {
            console.error(error);
            if (error instanceof HttpErrorResponse) {
                // Server or connection error happened
                if (!navigator.onLine) {
                    // Handle offline error
                    console.error('Browser Offline!');
                }
                else {
                    // Handle Http Error (4xx, 5xx, ect.)
                    const messageError = error.error ? error.error : error.message;
                    this.notificationService.showMessage(messageError, this.translate.instant('title.http.error'), NotificationType.error);
                }
            }
            else {
                this.notificationService.showMessage(error.message, 'title.not.http.error!', NotificationType.error);
                console.error(error);
            }
            // Always log the error
            // console.error(error);
        }
    }
};
ErrorsHandler.ctorParameters = () => [
    { type: NotificationService },
    { type: TranslateService }
];
ErrorsHandler = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [NotificationService, TranslateService])
], ErrorsHandler);

const moment = moment_;
let StringToDatePipe = class StringToDatePipe {
    transform(value) {
        if (value === '' || value === null || value === undefined)
            return null;
        return moment(value).toDate();
    }
};
StringToDatePipe = __decorate([
    Pipe({
        name: 'stringToDate'
    })
], StringToDatePipe);

let StringToDateModule = class StringToDateModule {
};
StringToDateModule = __decorate([
    NgModule({
        declarations: [
            StringToDatePipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            StringToDatePipe
        ]
    })
], StringToDateModule);

let SecondsToHoursMinutesPipe = class SecondsToHoursMinutesPipe {
    transform(totalSeconds) {
        if (!totalSeconds) {
            return '0';
        }
        const hours = Math.floor(totalSeconds / 3600);
        const minutes = Math.floor((totalSeconds % 3600) / 60);
        const seconds = totalSeconds % 60;
        let result = `${minutes.toString().padStart(1, '0')}:${seconds.toString().padStart(2, '0')}`;
        if (!!hours) {
            result = `${hours.toString()}:${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
        }
        return result;
    }
};
SecondsToHoursMinutesPipe = __decorate([
    Pipe({
        name: 'secondsToHoursMinutes'
    })
], SecondsToHoursMinutesPipe);

let SecondsToHoursMinutesModule = class SecondsToHoursMinutesModule {
};
SecondsToHoursMinutesModule = __decorate([
    NgModule({
        declarations: [
            SecondsToHoursMinutesPipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            SecondsToHoursMinutesPipe
        ]
    })
], SecondsToHoursMinutesModule);

let LocalizedDatePipe = class LocalizedDatePipe {
    constructor(config, translateService) {
        this.config = config;
        this.translateService = translateService;
    }
    transform(value, pattern = 'mediumDate') {
        const datePipe = new DatePipe(this.config.language);
        return datePipe.transform(value, pattern);
    }
};
LocalizedDatePipe.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] },
    { type: TranslateService }
];
LocalizedDatePipe = __decorate([
    Pipe({
        name: 'localizedDate', pure: false
    }),
    __param(0, Inject(INITSERVICE_OPTIONS)),
    __metadata("design:paramtypes", [Object, TranslateService])
], LocalizedDatePipe);

let LocalizedDateModule = class LocalizedDateModule {
};
LocalizedDateModule = __decorate([
    NgModule({
        declarations: [
            LocalizedDatePipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            LocalizedDatePipe
        ]
    })
], LocalizedDateModule);

let TruncatePipe = class TruncatePipe {
    transform(value, limit = 25, completeWords = false, ellipsis = '...') {
        if (value.length < limit)
            return `${value.substr(0, limit)}`;
        if (completeWords) {
            limit = value.substr(0, limit).lastIndexOf(' ');
        }
        return `${value.substr(0, limit)}${ellipsis}`;
    }
};
TruncatePipe = __decorate([
    Pipe({
        name: 'truncate'
    })
], TruncatePipe);

let TruncateModule = class TruncateModule {
};
TruncateModule = __decorate([
    NgModule({
        declarations: [
            TruncatePipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            TruncatePipe
        ]
    })
], TruncateModule);

let LeftPadPipe = class LeftPadPipe {
    transform(value, size) {
        return (String('0').repeat(size) + value).substr((size * -1), size);
    }
};
LeftPadPipe = __decorate([
    Pipe({
        name: 'leftPad'
    })
], LeftPadPipe);

let LeftPadModule = class LeftPadModule {
};
LeftPadModule = __decorate([
    NgModule({
        declarations: [
            LeftPadPipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            LeftPadPipe
        ]
    })
], LeftPadModule);

const locales = {
    en, es
};
let DateAgoPipe = class DateAgoPipe {
    constructor(config) {
        this.config = config;
        this.refresher = new Subscription();
        this.refreshNow = false;
        this.previousAgoExpression = '';
        this.refresher = interval(5000).pipe(startWith(0)).subscribe(_ => { this.refreshNow = true; });
    }
    ngOnDestroy() {
        this.refresher.unsubscribe();
    }
    transform(inputTime) {
        if (this.refreshNow) {
            this.refreshNow = false;
            const newAgoExpression = this.agoExpression(inputTime);
            this.previousAgoExpression = newAgoExpression;
            return newAgoExpression;
        }
        else {
            return this.previousAgoExpression;
        }
    }
    agoExpression(inputTime) {
        const timeText = distanceInWordsToNow(inputTime, { includeSeconds: true, locale: locales[this.config.language] });
        return timeText;
    }
};
DateAgoPipe.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] }
];
DateAgoPipe = __decorate([
    Pipe({
        name: 'dateAgo', pure: false
    }),
    __param(0, Inject(INITSERVICE_OPTIONS)),
    __metadata("design:paramtypes", [Object])
], DateAgoPipe);

let DateAgoModule = class DateAgoModule {
};
DateAgoModule = __decorate([
    NgModule({
        declarations: [
            DateAgoPipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            DateAgoPipe
        ]
    })
], DateAgoModule);

let SanitizeHTMLPipe = class SanitizeHTMLPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(html) {
        return this.domSanitizer.bypassSecurityTrustHtml(html);
    }
};
SanitizeHTMLPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SanitizeHTMLPipe = __decorate([
    Pipe({ name: 'sanitizeHTML' }),
    __metadata("design:paramtypes", [DomSanitizer])
], SanitizeHTMLPipe);

let SanitizeHTMLModule = class SanitizeHTMLModule {
};
SanitizeHTMLModule = __decorate([
    NgModule({
        declarations: [
            SanitizeHTMLPipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            SanitizeHTMLPipe
        ]
    })
], SanitizeHTMLModule);

let SanitizeStylePipe = class SanitizeStylePipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(css) {
        return this.domSanitizer.bypassSecurityTrustStyle(css);
    }
};
SanitizeStylePipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SanitizeStylePipe = __decorate([
    Pipe({ name: 'sanitizeStyle' }),
    __metadata("design:paramtypes", [DomSanitizer])
], SanitizeStylePipe);

let SanitizeStyleModule = class SanitizeStyleModule {
};
SanitizeStyleModule = __decorate([
    NgModule({
        declarations: [
            SanitizeStylePipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            SanitizeStylePipe
        ]
    })
], SanitizeStyleModule);

let BooleanToStringPipe = class BooleanToStringPipe {
    transform(value) {
        if (value)
            return "label.boolean.true";
        return "label.boolean.false";
    }
};
BooleanToStringPipe = __decorate([
    Pipe({
        name: 'booleanToString'
    })
], BooleanToStringPipe);

let BooleanToStringModule = class BooleanToStringModule {
};
BooleanToStringModule = __decorate([
    NgModule({
        declarations: [
            BooleanToStringPipe
        ],
        imports: [
            CommonModule
        ],
        exports: [
            BooleanToStringPipe
        ]
    })
], BooleanToStringModule);

class WebSocketAPI {
    constructor(socketMessageReceive, topic, webSocketEndPoint = 'http://localhost:7070/ws', zone) {
        this.zone = zone;
        this.topic = topic;
        this.socketMessageReceive = socketMessageReceive;
        this.webSocketEndPoint = webSocketEndPoint;
    }
    _connect() {
        const ws = new SockJS(this.webSocketEndPoint);
        this.stompClient = over(ws);
        // remove console log
        this.stompClient.debug = null;
        const THIS = this;
        THIS.stompClient.connect({}, (frame) => {
            THIS.stompClient.subscribe(THIS.topic, (event) => {
                this.zone.run(() => {
                    THIS.socketMessageReceive.onMessageReceived(JSON.parse(event.body));
                });
            });
        }, this.errorCallBack);
    }
    _disconnect() {
        if (this.stompClient !== null) {
            this.stompClient.disconnect();
        }
        console.log('Disconnected');
    }
    errorCallBack(error) {
        console.log('errorCallBack -> ' + error);
        setTimeout(() => {
            this._connect();
        }, 5000);
    }
    _sendMessage(channel, message) {
        this.stompClient.send(channel, {}, JSON.stringify(message));
    }
}

/*
 * Public API Surface of xdf-commons
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationService, BooleanToStringModule, BooleanToStringPipe, DIRECTION, DateAgoModule, DateAgoPipe, ErrorsHandler, HighlightDirective, INITSERVICE_OPTIONS, InitCommonsService, LeftPadModule, LeftPadPipe, LocalizedDateModule, LocalizedDatePipe, NotificationService, NotificationType, Pagination, SanitizeHTMLModule, SanitizeHTMLPipe, SanitizeStyleModule, SanitizeStylePipe, SecondsToHoursMinutesModule, SecondsToHoursMinutesPipe, SnackbarNotificationService, SortField, StringToDateModule, StringToDatePipe, ToastNotificationService, TruncateModule, TruncatePipe, User, WebSocketAPI, XdfCommonsModule };
//# sourceMappingURL=xdf-commons.js.map
